==> gnome-shell-extension-taskbar_53.0.orig.tar.gz: gnome-shell-extension-taskbar-53.0/README.md <==
![TaskBar Icon](https://extensions.gnome.org/static/extension-data/icons/icon_584.png)          
**GNOME Shell Extension TaskBar Version 53 for GNOME 3.10 - 3.22**  
zpydr@openmailbox.org        
https://extensions.gnome.org/extension/584/taskbar/             
https://github.com/zpydr/gnome-shell-extension-taskbar/         
https://launchpad.net/gnome-shell-extension-taskbar/            
                
Arch Linux User Repository              
https://aur.archlinux.org/packages/gnome-shell-extension-taskbar/               
        
Debian / Ubuntu PPA Repository                   
https://launchpad.net/~zpydr/+archive/gnome-shell-extension-taskbar/                        

TaskBar Installation Wiki                       
https://github.com/zpydr/gnome-shell-extension-taskbar/wiki/TaskBar-Installation/                               
        
GNOME Shell Extension TaskBar is free software and released under the GNU General Public License (GPL)          
https://www.gnu.org/licenses/       

TaskBar displays icons of running applications on the top panel or alternatively on a new bottom panel.        
Activate, minimize or close tasks with a simple click.          
TaskBar is a dock-like windows list on the top/bottom bar.      

Options:                        
Desktop button - toggle desktop view        
Workspace button - switch workspaces left/right-click: cycle forward/backwards      
Appview button - left/right-click: toggle appview/overview      
Favorites - add from dash       
Align position      
Resize panels + adjust icon, label and content sizes        
Top/bottom panel background color + opacity     
Bottom panel tray button - activate the message tray        
Tasks on all workspaces		  
Tasks label     
Tasks application menu         
Close tasks with a right/middle click           
Activate tasks on hover         
Scroll tasks/workspaces         
Separators          
Thumbnail/label-preview         
Preview color + opacity      
Color or hide menu buttons         
Disable hot corner          
        
Language support:       
Chinese by wsxy162        
Czech by michal-ruzicka     
French by narzb       
German by jonnius       
Spanish by Testoriano		

Credit to Xes, flubshi, rogst, Baltix, boennhoff, skoslowski, rgeary1, hkskoglund, michal-ruzicka, skochxxl, tuhaihe, to-ba, tobimensch        
        
![TaskBar Image](https://extensions.gnome.org/static/extension-data/screenshots/screenshot_584_PSh3ecJ.png)
        
GNOME Shell Extension TaskBar           
Copyright (C) 2016 zpydr             
                
This program is free software: you can redistribute it and/or modify            
it under the terms of the GNU General Public License as published by            
the Free Software Foundation, either version 3 of the License, or               
(at your option) any later version.             
                
This program is distributed in the hope that it will be useful,         
but WITHOUT ANY WARRANTY; without even the implied warranty of          
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            
GNU General Public License for more details.            
                
You should have received a copy of the GNU General Public License               
along with this program. If not, see https://www.gnu.org/licenses/.              
                
zpydr@openmailbox.org            
                
![GPL Image](https://www.gnu.org/graphics/gplv3-127x51.png)

==> gnome-shell-extension-taskbar_54.0.orig.tar.gz: gnome-shell-extension-taskbar-54.0/README.md <==
![TaskBar Icon](https://extensions.gnome.org/extension-data/icons/icon_584_ZS33QUn.png)          
**GNOME Shell Extension TaskBar**    
Copyright (C) 2013-2017 zpydr             
                
This program is free software: you can redistribute it and/or modify            
it under the terms of the GNU General Public License as published by            
the Free Software Foundation, either version 3 of the License, or               
(at your option) any later version.             
                
This program is distributed in the hope that it will be useful,         
but WITHOUT ANY WARRANTY; without even the implied warranty of          
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            
GNU General Public License for more details.            
                
You should have received a copy of the GNU General Public License               
along with this program. If not, see https://www.gnu.org/licenses/.              
                
zpydr@openmailbox.org            
                
![GPL Image](https://www.gnu.org/graphics/gplv3-127x51.png)             
        
         
![TaskBar Image](https://extensions.gnome.org/extension-data/screenshots/screenshot_584_PSh3ecJ.png)        
        
 **Version 54 for GNOME 3.10 - 3.24**       
        
https://extensions.gnome.org/extension/584/taskbar/             
https://github.com/zpydr/gnome-shell-extension-taskbar/         
https://launchpad.net/gnome-shell-extension-taskbar/            
                
Arch Linux User Repository              
https://aur.archlinux.org/packages/gnome-shell-extension-taskbar/               
        
Debian / Ubuntu PPA Repository                   
https://launchpad.net/~zpydr/+archive/gnome-shell-extension-taskbar/                        

TaskBar Installation Wiki                       
https://github.com/zpydr/gnome-shell-extension-taskbar/wiki/TaskBar-Installation/                               
        
GNOME Shell Extension TaskBar is free software and released under the GNU General Public License (GPL)          
https://www.gnu.org/licenses/       

TaskBar displays icons of running applications on the top panel or alternatively on a new bottom panel.        
Activate, minimize or close tasks with a simple click.          
TaskBar is a dock-like windows list on the top/bottom bar.      

Options:                        
Desktop button - toggle desktop view        
Workspace button - switch workspaces left/right-click: cycle forward/backwards      
Appview button - left/right-click: toggle appview/overview      
Favorites - add from dash       
Align position      
Resize panels + adjust icon, label and content sizes        
Top/bottom panel background color + opacity     
Bottom panel tray button - activate the message tray        
Tasks on all workspaces		  
Tasks label     
Tasks application menu         
Close tasks with a right/middle click           
Activate tasks on hover         
Scroll tasks/workspaces         
Separators          
Thumbnail/label-preview         
Preview color + opacity      
Color or hide menu buttons         
Disable hot corner          
        
Language support:       
Chinese by wsxy162        
Czech by michal-ruzicka     
French by narzb       
German by jonnius       
Russian by dersteinkauz     
Spanish by Testoriano		

Credit to Xes, flubshi, rogst, Baltix, boennhoff, skoslowski, rgeary1, hkskoglund, michal-ruzicka, skochxxl, tuhaihe, to-ba, tobimensch, navarrano
